# Changelog

## [1.0.3](https://github.com/kisiac/kisiac/compare/v1.0.2...v1.0.3) (2025-11-24)


### Documentation

* update cli help ([8a436db](https://github.com/kisiac/kisiac/commit/8a436dbf32a9bb15f0c3a0f222d1240e2a7859af))

## [1.0.2](https://github.com/kisiac/kisiac/compare/v1.0.1...v1.0.2) (2025-11-24)


### Bug Fixes

* use correct package for building ([f91bd42](https://github.com/kisiac/kisiac/commit/f91bd42750005194913938017fc2e10759ef9df9))

## [1.0.1](https://github.com/kisiac/kisiac/compare/v1.0.0...v1.0.1) (2025-11-24)


### Miscellaneous Chores

* release 1.0.0 ([168e6ce](https://github.com/kisiac/kisiac/commit/168e6cecee807f254f8fefefe2bc87f3c48272e2))
* Release 1.0.1 ([a3e7ab2](https://github.com/kisiac/kisiac/commit/a3e7ab2465bbb9a56ad909b3e5b50193fdd355cd))

## 1.0.0 (2025-11-24)


### Miscellaneous Chores

* release 1.0.0 ([168e6ce](https://github.com/koesterlab/kisiac/commit/168e6cecee807f254f8fefefe2bc87f3c48272e2))
